@@ -1,9 +1,9 @@
 use super::*;
 
 mod activation_factory;
-mod object;
+mod inspectable;
 mod unknown;
 
 pub use activation_factory::*;
-pub use object::*;
+pub use inspectable::*;
 pub use unknown::*;
