@@ -1,5 +1,5 @@
 use crate::*;
-use bindings::Windows::Win32::WinRT::{IWeakReference, IWeakReferenceSource};
+use bindings::Windows::Win32::System::WinRT::{IWeakReference, IWeakReferenceSource};
 use std::marker::PhantomData;
 
 /// `Weak` holds a non-owning reference to an object.
@@ -15,6 +15,7 @@ impl<I: Interface> Weak<I> {
     /// Attempts to upgrade the weak reference to a strong reference.
     pub fn upgrade(&self) -> Option<I> {
         self.0.as_ref().and_then(|inner| unsafe {
+            // Calls IWeakReference's Resolve ABI directly as the metadata incorrectly types it as returning IInspectable.
             let mut result = None;
             let _ = (inner.vtable().3)(inner.abi(), &I::IID, &mut result as *mut _ as _);
             result
